graphviz

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 3, 2019 License: Apache-2.0 Imports: 3 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ApplicationDrawer

type ApplicationDrawer struct {
	// contains filtered or unexported fields
}

EXTEND COMPONENT

func (ApplicationDrawer) Draw

func (ComponentDrawer ApplicationDrawer) Draw(hidePlanned bool) string

Decorate Draw function

type OutgoingTeamRelation

type OutgoingTeamRelation struct {
	Relationship   string
	ToTeam         string
	ForApplication string
}

type ProjectDrawer

type ProjectDrawer struct {
	// contains filtered or unexported fields
}

func CreateProjectDrawer

func CreateProjectDrawer(Project *model.Project, iconPath string) *ProjectDrawer

Factory

func (*ProjectDrawer) DrawComplete

func (projectDrawer *ProjectDrawer) DrawComplete(hidePlanned bool) string

Decorate Draw function

func (*ProjectDrawer) DrawComponent

func (ProjectDrawer *ProjectDrawer) DrawComponent(Component *model.Application) string

Decorate Draw function - Draws only a component with its direct dependencies and direct callers

type TeamDependencyDrawer

type TeamDependencyDrawer struct {
	// contains filtered or unexported fields
}

func CreateTeamDependencyDrawer

func CreateTeamDependencyDrawer(Project *model.Project, summaryRelationOnly bool) *TeamDependencyDrawer

Factory

func (*TeamDependencyDrawer) DrawComplete

func (d *TeamDependencyDrawer) DrawComplete() string

Decorate Draw function

func (*TeamDependencyDrawer) DrawTeam

func (d *TeamDependencyDrawer) DrawTeam(team string, applications []*model.Application, tableHeaderColor string) string

Decorate Draw function - Draws only a component with its direct dependencies and direct callers

Jump to