Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ApplicationDrawer ¶
type ApplicationDrawer struct {
// contains filtered or unexported fields
}
EXTEND COMPONENT
func (ApplicationDrawer) Draw ¶
func (ComponentDrawer ApplicationDrawer) Draw(hidePlanned bool) string
Decorate Draw function
type OutgoingTeamRelation ¶
type ProjectDrawer ¶
type ProjectDrawer struct {
// contains filtered or unexported fields
}
func CreateProjectDrawer ¶
func CreateProjectDrawer(Project *model.Project, iconPath string) *ProjectDrawer
Factory
func (*ProjectDrawer) DrawComplete ¶
func (projectDrawer *ProjectDrawer) DrawComplete(hidePlanned bool) string
Decorate Draw function
func (*ProjectDrawer) DrawComponent ¶
func (ProjectDrawer *ProjectDrawer) DrawComponent(Component *model.Application) string
Decorate Draw function - Draws only a component with its direct dependencies and direct callers
type TeamDependencyDrawer ¶
type TeamDependencyDrawer struct {
// contains filtered or unexported fields
}
func CreateTeamDependencyDrawer ¶
func CreateTeamDependencyDrawer(Project *model.Project, summaryRelationOnly bool) *TeamDependencyDrawer
Factory
func (*TeamDependencyDrawer) DrawComplete ¶
func (d *TeamDependencyDrawer) DrawComplete() string
Decorate Draw function
func (*TeamDependencyDrawer) DrawTeam ¶
func (d *TeamDependencyDrawer) DrawTeam(team string, applications []*model.Application, tableHeaderColor string) string
Decorate Draw function - Draws only a component with its direct dependencies and direct callers
Click to show internal directories.
Click to hide internal directories.